==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/ServerSecurityAlertPolicy.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.sql.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [ServerSecurityAlertPolicy].
 */
@PulumiTagMarker
public class ServerSecurityAlertPolicyResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ServerSecurityAlertPolicyArgs = ServerSecurityAlertPolicyArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ServerSecurityAlertPolicyArgsBuilder.() -> Unit) {
        val builder = ServerSecurityAlertPolicyArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ServerSecurityAlertPolicy {
        val builtJavaResource =
            com.pulumi.azurenative.sql.ServerSecurityAlertPolicy(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ServerSecurityAlertPolicy(builtJavaResource)
    }
}

/**
 * A server security alert policy.
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2020-11-01-preview.
 * Other available API versions: 2017-03-01-preview, 2022-11-01-preview, 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Update a server's threat detection policy with all parameters
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var serverSecurityAlertPolicy = new AzureNative.Sql.ServerSecurityAlertPolicy("serverSecurityAlertPolicy", new()
 *     {
 *         DisabledAlerts = new[]
 *         {
 *             "Access_Anomaly",
 *             "Usage_Anomaly",
 *         },
 *         EmailAccountAdmins = true,
 *         EmailAddresses = new[]
 *         {
 *             "testSecurityAlert@microsoft.com",
 *         },
 *         ResourceGroupName = "securityalert-4799",
 *         RetentionDays = 5,
 *         SecurityAlertPolicyName = "Default",
 *         ServerName = "securityalert-6440",
 *         State = AzureNative.Sql.SecurityAlertsPolicyState.Enabled,
 *         StorageAccountAccessKey = "sdlfkjabc+sdlfkjsdlkfsjdfLDKFTERLKFDFKLjsdfksjdflsdkfD2342309432849328476458/3RSD==",
 *         StorageEndpoint = "https://mystorage.blob.core.windows.net",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewServerSecurityAlertPolicy(ctx, "serverSecurityAlertPolicy", &sql.ServerSecurityAlertPolicyArgs{
 * 			DisabledAlerts: pulumi.StringArray{
 * 				pulumi.String("Access_Anomaly"),
 * 				pulumi.String("Usage_Anomaly"),
 * 			},
 * 			EmailAccountAdmins: pulumi.Bool(true),
 * 			EmailAddresses: pulumi.StringArray{
 * 				pulumi.String("testSecurityAlert@microsoft.com"),
 * 			},
 * 			ResourceGroupName:       pulumi.String("securityalert-4799"),
 * 			RetentionDays:           pulumi.Int(5),
 * 			SecurityAlertPolicyName: pulumi.String("Default"),
 * 			ServerName:              pulumi.String("securityalert-6440"),
 * 			State:                   sql.SecurityAlertsPolicyStateEnabled,
 * 			StorageAccountAccessKey: pulumi.String("sdlfkjabc+sdlfkjsdlkfsjdfLDKFTERLKFDFKLjsdfksjdflsdkfD2342309432849328476458/3RSD=="),
 * 			StorageEndpoint:         pulumi.String("https://mystorage.blob.core.windows.net"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.ServerSecurityAlertPolicy;
 * import com.pulumi.azurenative.sql.ServerSecurityAlertPolicyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var serverSecurityAlertPolicy = new ServerSecurityAlertPolicy("serverSecurityAlertPolicy", ServerSecurityAlertPolicyArgs.builder()
 *             .disabledAlerts(
 *                 "Access_Anomaly",
 *                 "Usage_Anomaly")
 *             .emailAccountAdmins(true)
 *             .emailAddresses("testSecurityAlert@microsoft.com")
 *             .resourceGroupName("securityalert-4799")
 *             .retentionDays(5)
 *             .securityAlertPolicyName("Default")
 *             .serverName("securityalert-6440")
 *             .state("Enabled")
 *             .storageAccountAccessKey("sdlfkjabc+sdlfkjsdlkfsjdfLDKFTERLKFDFKLjsdfksjdflsdkfD2342309432849328476458/3RSD==")
 *             .storageEndpoint("https://mystorage.blob.core.windows.net")
 *             .build());
 *     }
 * }
 * ```
 * ### Update a server's threat detection policy with minimal parameters
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var serverSecurityAlertPolicy = new AzureNative.Sql.ServerSecurityAlertPolicy("serverSecurityAlertPolicy", new()
 *     {
 *         ResourceGroupName = "securityalert-4799",
 *         SecurityAlertPolicyName = "Default",
 *         ServerName = "securityalert-6440",
 *         State = AzureNative.Sql.SecurityAlertsPolicyState.Enabled,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewServerSecurityAlertPolicy(ctx, "serverSecurityAlertPolicy", &sql.ServerSecurityAlertPolicyArgs{
 * 			ResourceGroupName:       pulumi.String("securityalert-4799"),
 * 			SecurityAlertPolicyName: pulumi.String("Default"),
 * 			ServerName:              pulumi.String("securityalert-6440"),
 * 			State:                   sql.SecurityAlertsPolicyStateEnabled,
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.ServerSecurityAlertPolicy;
 * import com.pulumi.azurenative.sql.ServerSecurityAlertPolicyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var serverSecurityAlertPolicy = new ServerSecurityAlertPolicy("serverSecurityAlertPolicy", ServerSecurityAlertPolicyArgs.builder()
 *             .resourceGroupName("securityalert-4799")
 *             .securityAlertPolicyName("Default")
 *             .serverName("securityalert-6440")
 *             .state("Enabled")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:ServerSecurityAlertPolicy Default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/securityAlertPolicies/{securityAlertPolicyName}
 * ```
 */
public class ServerSecurityAlertPolicy internal constructor(
    override val javaResource: com.pulumi.azurenative.sql.ServerSecurityAlertPolicy,
) : KotlinCustomResource(javaResource, ServerSecurityAlertPolicyMapper) {
    /**
     * Specifies the UTC creation time of the policy.
     */
    public val creationTime: Output<String>
        get() = javaResource.creationTime().applyValue({ args0 -> args0 })

    /**
     * Specifies an array of alerts that are disabled. Allowed values are: Sql_Injection, Sql_Injection_Vulnerability, Access_Anomaly, Data_Exfiltration, Unsafe_Action, Brute_Force
     */
    public val disabledAlerts: Output<List<String>>?
        get() = javaResource.disabledAlerts().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Specifies that the alert is sent to the account administrators.
     */
    public val emailAccountAdmins: Output<Boolean>?
        get() = javaResource.emailAccountAdmins().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Specifies an array of e-mail addresses to which the alert is sent.
     */
    public val emailAddresses: Output<List<String>>?
        get() = javaResource.emailAddresses().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Specifies the number of days to keep in the Threat Detection audit logs.
     */
    public val retentionDays: Output<Int>?
        get() = javaResource.retentionDays().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Specifies the state of the policy, whether it is enabled or disabled or a policy has not been applied yet on the specific database.
     */
    public val state: Output<String>
        get() = javaResource.state().applyValue({ args0 -> args0 })

    /**
     * Specifies the identifier key of the Threat Detection audit storage account.
     */
    public val storageAccountAccessKey: Output<String>?
        get() = javaResource.storageAccountAccessKey().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs.
     */
    public val storageEndpoint: Output<String>?
        get() = javaResource.storageEndpoint().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * SystemData of SecurityAlertPolicyResource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ServerSecurityAlertPolicyMapper : ResourceMapper<ServerSecurityAlertPolicy> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.sql.ServerSecurityAlertPolicy::class == javaResource::class

    override fun map(javaResource: Resource): ServerSecurityAlertPolicy =
        ServerSecurityAlertPolicy(
            javaResource as
                com.pulumi.azurenative.sql.ServerSecurityAlertPolicy,
        )
}

/**
 * @see [ServerSecurityAlertPolicy].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ServerSecurityAlertPolicy].
 */
public suspend fun serverSecurityAlertPolicy(
    name: String,
    block: suspend ServerSecurityAlertPolicyResourceBuilder.() -> Unit,
): ServerSecurityAlertPolicy {
    val builder = ServerSecurityAlertPolicyResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ServerSecurityAlertPolicy].
 * @param name The _unique_ name of the resulting resource.
 */
public fun serverSecurityAlertPolicy(name: String): ServerSecurityAlertPolicy {
    val builder = ServerSecurityAlertPolicyResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/ServerSecurityAlertPolicy.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.sql.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [ServerSecurityAlertPolicy].
 */
@PulumiTagMarker
public class ServerSecurityAlertPolicyResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ServerSecurityAlertPolicyArgs = ServerSecurityAlertPolicyArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ServerSecurityAlertPolicyArgsBuilder.() -> Unit) {
        val builder = ServerSecurityAlertPolicyArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ServerSecurityAlertPolicy {
        val builtJavaResource =
            com.pulumi.azurenative.sql.ServerSecurityAlertPolicy(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ServerSecurityAlertPolicy(builtJavaResource)
    }
}

/**
 * A server security alert policy.
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2020-11-01-preview.
 * Other available API versions: 2017-03-01-preview, 2022-11-01-preview, 2023-02-01-preview, 2023-05-01-preview, 2023-08-01-preview.
 * ## Example Usage
 * ### Update a server's threat detection policy with all parameters
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var serverSecurityAlertPolicy = new AzureNative.Sql.ServerSecurityAlertPolicy("serverSecurityAlertPolicy", new()
 *     {
 *         DisabledAlerts = new[]
 *         {
 *             "Access_Anomaly",
 *             "Usage_Anomaly",
 *         },
 *         EmailAccountAdmins = true,
 *         EmailAddresses = new[]
 *         {
 *             "testSecurityAlert@microsoft.com",
 *         },
 *         ResourceGroupName = "securityalert-4799",
 *         RetentionDays = 5,
 *         SecurityAlertPolicyName = "Default",
 *         ServerName = "securityalert-6440",
 *         State = AzureNative.Sql.SecurityAlertsPolicyState.Enabled,
 *         StorageAccountAccessKey = "sdlfkjabc+sdlfkjsdlkfsjdfLDKFTERLKFDFKLjsdfksjdflsdkfD2342309432849328476458/3RSD==",
 *         StorageEndpoint = "https://mystorage.blob.core.windows.net",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewServerSecurityAlertPolicy(ctx, "serverSecurityAlertPolicy", &sql.ServerSecurityAlertPolicyArgs{
 * 			DisabledAlerts: pulumi.StringArray{
 * 				pulumi.String("Access_Anomaly"),
 * 				pulumi.String("Usage_Anomaly"),
 * 			},
 * 			EmailAccountAdmins: pulumi.Bool(true),
 * 			EmailAddresses: pulumi.StringArray{
 * 				pulumi.String("testSecurityAlert@microsoft.com"),
 * 			},
 * 			ResourceGroupName:       pulumi.String("securityalert-4799"),
 * 			RetentionDays:           pulumi.Int(5),
 * 			SecurityAlertPolicyName: pulumi.String("Default"),
 * 			ServerName:              pulumi.String("securityalert-6440"),
 * 			State:                   sql.SecurityAlertsPolicyStateEnabled,
 * 			StorageAccountAccessKey: pulumi.String("sdlfkjabc+sdlfkjsdlkfsjdfLDKFTERLKFDFKLjsdfksjdflsdkfD2342309432849328476458/3RSD=="),
 * 			StorageEndpoint:         pulumi.String("https://mystorage.blob.core.windows.net"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.ServerSecurityAlertPolicy;
 * import com.pulumi.azurenative.sql.ServerSecurityAlertPolicyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var serverSecurityAlertPolicy = new ServerSecurityAlertPolicy("serverSecurityAlertPolicy", ServerSecurityAlertPolicyArgs.builder()
 *             .disabledAlerts(
 *                 "Access_Anomaly",
 *                 "Usage_Anomaly")
 *             .emailAccountAdmins(true)
 *             .emailAddresses("testSecurityAlert@microsoft.com")
 *             .resourceGroupName("securityalert-4799")
 *             .retentionDays(5)
 *             .securityAlertPolicyName("Default")
 *             .serverName("securityalert-6440")
 *             .state("Enabled")
 *             .storageAccountAccessKey("sdlfkjabc+sdlfkjsdlkfsjdfLDKFTERLKFDFKLjsdfksjdflsdkfD2342309432849328476458/3RSD==")
 *             .storageEndpoint("https://mystorage.blob.core.windows.net")
 *             .build());
 *     }
 * }
 * ```
 * ### Update a server's threat detection policy with minimal parameters
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var serverSecurityAlertPolicy = new AzureNative.Sql.ServerSecurityAlertPolicy("serverSecurityAlertPolicy", new()
 *     {
 *         ResourceGroupName = "securityalert-4799",
 *         SecurityAlertPolicyName = "Default",
 *         ServerName = "securityalert-6440",
 *         State = AzureNative.Sql.SecurityAlertsPolicyState.Enabled,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewServerSecurityAlertPolicy(ctx, "serverSecurityAlertPolicy", &sql.ServerSecurityAlertPolicyArgs{
 * 			ResourceGroupName:       pulumi.String("securityalert-4799"),
 * 			SecurityAlertPolicyName: pulumi.String("Default"),
 * 			ServerName:              pulumi.String("securityalert-6440"),
 * 			State:                   sql.SecurityAlertsPolicyStateEnabled,
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.ServerSecurityAlertPolicy;
 * import com.pulumi.azurenative.sql.ServerSecurityAlertPolicyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var serverSecurityAlertPolicy = new ServerSecurityAlertPolicy("serverSecurityAlertPolicy", ServerSecurityAlertPolicyArgs.builder()
 *             .resourceGroupName("securityalert-4799")
 *             .securityAlertPolicyName("Default")
 *             .serverName("securityalert-6440")
 *             .state("Enabled")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:ServerSecurityAlertPolicy Default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/securityAlertPolicies/{securityAlertPolicyName}
 * ```
 */
public class ServerSecurityAlertPolicy internal constructor(
    override val javaResource: com.pulumi.azurenative.sql.ServerSecurityAlertPolicy,
) : KotlinCustomResource(javaResource, ServerSecurityAlertPolicyMapper) {
    /**
     * Specifies the UTC creation time of the policy.
     */
    public val creationTime: Output<String>
        get() = javaResource.creationTime().applyValue({ args0 -> args0 })

    /**
     * Specifies an array of alerts that are disabled. Allowed values are: Sql_Injection, Sql_Injection_Vulnerability, Access_Anomaly, Data_Exfiltration, Unsafe_Action, Brute_Force
     */
    public val disabledAlerts: Output<List<String>>?
        get() = javaResource.disabledAlerts().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Specifies that the alert is sent to the account administrators.
     */
    public val emailAccountAdmins: Output<Boolean>?
        get() = javaResource.emailAccountAdmins().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Specifies an array of e-mail addresses to which the alert is sent.
     */
    public val emailAddresses: Output<List<String>>?
        get() = javaResource.emailAddresses().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Specifies the number of days to keep in the Threat Detection audit logs.
     */
    public val retentionDays: Output<Int>?
        get() = javaResource.retentionDays().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Specifies the state of the policy, whether it is enabled or disabled or a policy has not been applied yet on the specific database.
     */
    public val state: Output<String>
        get() = javaResource.state().applyValue({ args0 -> args0 })

    /**
     * Specifies the identifier key of the Threat Detection audit storage account.
     */
    public val storageAccountAccessKey: Output<String>?
        get() = javaResource.storageAccountAccessKey().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs.
     */
    public val storageEndpoint: Output<String>?
        get() = javaResource.storageEndpoint().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * SystemData of SecurityAlertPolicyResource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ServerSecurityAlertPolicyMapper : ResourceMapper<ServerSecurityAlertPolicy> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.sql.ServerSecurityAlertPolicy::class == javaResource::class

    override fun map(javaResource: Resource): ServerSecurityAlertPolicy =
        ServerSecurityAlertPolicy(
            javaResource as
                com.pulumi.azurenative.sql.ServerSecurityAlertPolicy,
        )
}

/**
 * @see [ServerSecurityAlertPolicy].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ServerSecurityAlertPolicy].
 */
public suspend fun serverSecurityAlertPolicy(
    name: String,
    block: suspend ServerSecurityAlertPolicyResourceBuilder.() -> Unit,
): ServerSecurityAlertPolicy {
    val builder = ServerSecurityAlertPolicyResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ServerSecurityAlertPolicy].
 * @param name The _unique_ name of the resulting resource.
 */
public fun serverSecurityAlertPolicy(name: String): ServerSecurityAlertPolicy {
    val builder = ServerSecurityAlertPolicyResourceBuilder()
    builder.name(name)
    return builder.build()
}
